# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.4.0] 2022-09-21

### Added

### Changed
* Fixed workflow errors.

### Removed


## [0.3.1] 2022-03-23

### Added

### Changed

### Removed


## [0.3.0] 2022-03-22

### Added
- Workflow for changelog check.
- Support for python 3.10

### Changed
- Update build workflow version

### Removed
- Release candidate option.
